@@ -1,42 +1,72 @@
 import time
-from datetime import timedelta, datetime
-from operator import sub, add
+from datetime import datetime, timedelta
+from operator import add, sub
+from typing import Any, Callable, Dict, Optional, TYPE_CHECKING, TypeVar, \
+    Union
 
 from jwt import PyJWT
+
 from jwt_rsa.rsa import RSAPrivateKey, RSAPublicKey
 
+if TYPE_CHECKING:
+    # pylama:ignore=E0602
+    DateType = Union[timedelta, datetime, float, int, ellipsis]
+else:
+    DateType = Union[timedelta, datetime, float, int, type(Ellipsis)]
+
+R = TypeVar('R')
+
 
 class JWT:
     __slots__ = ('__private_key', '__public_key', '__jwt',
-                 '__expires', '__nbf_delta')
+                 '__expires', '__nbf_delta', '__algorithm')
 
-    _nil = object()
     DEFAULT_EXPIRATION = 86400 * 30  # one month
     NBF_DELTA = 20
+    ALGORITHMS = tuple({
+        'RS256', 'RS384', 'RS512', 'ES256', 'ES384',
+        'ES521', 'ES512', 'PS256', 'PS384', 'PS512'
+    })
 
-    def __init__(self, private_key: RSAPrivateKey=None,
-                 public_key: RSAPublicKey=None, expires=None,
-                 nbf_delta=None):
+    def __init__(
+        self,
+        private_key: Optional[RSAPrivateKey] = None,
+        public_key: Optional[RSAPublicKey] = None,
+        expires: Optional[int] = None,
+        nbf_delta: Optional[int] = None,
+        algorithm: str = "RS512"
+    ):
 
         self.__private_key = private_key
         self.__public_key = public_key
-        self.__jwt = PyJWT(algorithms={'RS512'})
+        self.__jwt = PyJWT(algorithms=self.ALGORITHMS)
         self.__expires = expires or self.DEFAULT_EXPIRATION
         self.__nbf_delta = nbf_delta or self.NBF_DELTA
+        self.__algorithm = algorithm
 
-    def _date_to_timestamp(self, value, default, timedelta_func=add):
+    def _date_to_timestamp(
+        self,
+        value: DateType,
+        default: Callable[[], R],
+        timedelta_func: Callable[[float, float], int] = add
+    ) -> Union[int, float, R]:
         if isinstance(value, timedelta):
             return timedelta_func(time.time(), value.total_seconds())
         elif isinstance(value, datetime):
             return value.timestamp()
         elif isinstance(value, (int, float)):
             return value
-        elif value is self._nil:
+        elif value is Ellipsis:
             return default()
 
         raise ValueError(type(value))
 
-    def encode(self, expired=_nil, nbf=_nil, **claims) -> str:
+    def encode(
+        self,
+        expired: DateType = ...,
+        nbf: DateType = ...,
+        **claims: int
+    ) -> str:
         if not self.__private_key:
             raise RuntimeError("Can't encode without private key")
 
@@ -61,18 +91,20 @@ class JWT:
         return self.__jwt.encode(
             claims,
             self.__private_key,
-            algorithm='RS512',
+            algorithm=self.__algorithm,
         ).decode()
 
-    def decode(self, token: str, verify=True, **kwargs) -> dict:
+    def decode(
+        self, token: str, verify: bool = True, **kwargs: Any
+    ) -> Dict[str, Any]:
         if not self.__public_key:
             raise RuntimeError("Can't decode without public key")
 
         return self.__jwt.decode(
-            token.encode(),
+            token,
             key=self.__public_key,
             verify=verify,
-            algorithms={'RS512'},
+            algorithms=self.ALGORITHMS,
             **kwargs
         )
 
